@@ -39,7 +39,7 @@ import json
 import datetime
 
 __name__ = 'BenBotAsync'
-__version__ = '2.3.0'
+__version__ = '2.3.1'
 __author__ = 'xMistt'
 
 BEN_BOT_BASE = 'https://benbotfn.tk/api/v1'
@@ -64,7 +64,7 @@ async def json_or_text(response: aiohttp.ClientResponse) -> Union[str, dict]:
 async def set_default_loadout(client: fortnitepy.Client, config: dict, member: fortnitepy.PartyMember) -> None:
     """Function which can be used with fortnitepy to set the default loadout."""
 
-    party_update_meta = client.user.party  # Saves direct route to the party_update_meta object.
+    party_update_meta = client.party if client.party else client.user.party  # Saves direct route to the party_update_meta object.
     kairos_profile = member.display_name  # Used to generated iOS token required for mass cosmetic updates.
 
     unique_ios_token = codecs.decode(
